@@ -2,23 +2,21 @@ import subprocess
 import numpy
 import matplotlib.pyplot as plt
 from matplotlib import colors
+
 try:
     import xarray
 except:
     subprocess.run('pip install xarray',shell='true')
     import xarray
-
-try:
-    from osgeo import gdal
-except:
-    subprocess.run('conda install -c conda-forge gdal',shell='true')
-    from osgeo import gdal
-
 try:
     import sklearn
 except:
     subprocess.run('pip install -U scikit-learn',shell='true')
     import sklearn
+try:
+    from osgeo import gdal
+except:
+    raise ModuleNotFoundError('You have to install gdal first with this command "conda install -c conda-forge gdal"')
 
 class objearth():
     def __init__(self):
